diff --git a/lib/ssh/src/ssh_connection_handler.erl b/lib/ssh/src/ssh_connection_handler.erl
index 3462b98..bc4115c 100644
--- a/lib/ssh/src/ssh_connection_handler.erl
+++ b/lib/ssh/src/ssh_connection_handler.erl
@@ -441,6 +441,21 @@ userauth(#ssh_msg_userauth_info_request{} = Msg,
     send_msg(Reply, State),
     {next_state, userauth, next_packet(State#state{ssh_params = Ssh})};
 
+userauth(#ssh_msg_userauth_pk_ok{} = Msg,
+	 #state{ssh_params = #ssh{role = client}} = State) ->
+    %% This probably isn't a pk_ok message
+    case Msg#ssh_msg_userauth_pk_ok.key_blob of
+	<< ?UINT32(Len1), Inst:Len1/binary, ?UINT32(Len2), Lang:Len2/binary, ?UINT32(NumPrompts), Data/binary >>
+	when size(Data) >= 3 * NumPrompts->
+	    InfoRequest = #ssh_msg_userauth_info_request{
+	      name = Msg#ssh_msg_userauth_pk_ok.algorithm_name,
+	      instruction = Inst,
+		language_tag = Lang,
+	      num_prompts = NumPrompts,
+	      data = Data},
+	    userauth(InfoRequest, State)
+    end;
+
 userauth(#ssh_msg_userauth_info_response{} = Msg, 
 	 #state{ssh_params = #ssh{role = server} = Ssh0} = State) ->
     {ok, {Reply, Ssh}} = ssh_auth:handle_userauth_info_response(Msg, Ssh0),
